==> comphep-4.4.96.tgz: comphep-4.4.96/src/num/include/clhapdf.h <==
/*
 * Copyright (C) 2007, Alexander Sherstnev 
 * Copyright (C) 2001-2007, CompHEP COllaboration
 *------------------------------------------------------
 * $Id$
 *
 * $Log$
*/
#ifndef __SF_CLHAPDF__
#define __SF_CLHAPDF__

#define f2cFortran

#include "cfortran.h"

PROTOCCALLSFSUB1(initpdfset,initpdfset,STRINGV)
#define initpdfset(name) \
CCALLSFSUB1(initpdfset,initpdfset,STRINGV,name) 

PROTOCCALLSFSUB1(initpdf,initpdf,INT)
#define initpdf(mem) \
CCALLSFSUB1(initpdf,initpdf,INT,mem) 

PROTOCCALLSFSUB2(getlam5,getlam5,INT,DOUBLE)
#define getlam5(mem,qcdl5) \
CCALLSFSUB2(getlam5,getlam5,INT,DOUBLE,mem,qcdl5)

PROTOCCALLSFSUB3(evolvepdf,evolvepdf,DOUBLE,DOUBLE,DOUBLEV)
#define evolvepdf(x,Q,pfg) \
CCALLSFSUB3(evolvepdf,evolvepdf,DOUBLE,DOUBLE,DOUBLEV,x,Q,pdf) 
/*
PROTOCCALLSFSUB1(getorderas,getorderas,INT)
#define getorderas(mem) \
CCALLSFSUB1(getorderas,getorderas,INT,order) 
*/
/* PROTOCCALLSFSUBn is optional for C, but mandatory for C++.

PROTOCCALLSFSUBn(ROUTINE_NAME,routine_name,argtype_1,...,argtype_n)
#define     Routine_name(argname_1,..,argname_n)               \
CCALLSFSUBn(ROUTINE_NAME,routine_name,argtype_1,...,argtype_n, argname_1,..,argname_n) 

PROTOCCALLSFFUNn(routine_type,ROUTINE_NAME,routine_name,argtype_1,...,argtype_n)
#define     Routine_name(argname_1,..,argname_n)               \
CCALLSFFUNn(ROUTINE_NAME,routine_name,argtype_1,...,argtype_n, argname_1,..,argname_n) 

*/

PROTOCCALLSFFUN1(DOUBLE,alphaspdf,alphaspdf,DOUBLE)
#define alphaspdf(Q) \
CCALLSFFUN1(alphaspdf,alphaspdf,DOUBLE,Q)

PROTOCCALLSFFUN2(DOUBLE,QCDLAM,qcdlam,INT,INT)
#define qcdlam(set,mem) CCALLSFFUN2(QCDLAM,qcdlam,INT,INT,set,mem)

PROTOCCALLSFFUN0(INT,qcdorder,qcdorder)
#define qcdorder() \
CCALLSFFUN0(qcdorder,qcdorder)

#endif

==> comphep-4.4.97.tgz: comphep-4.4.97/src/num/include/clhapdf.h <==
/*
 * Copyright (C) 2007, Alexander Sherstnev 
 * Copyright (C) 2001-2007, CompHEP COllaboration
 *------------------------------------------------------
 * $Id$
 *
 * $Log$
*/
#ifndef __SF_Clhapdf_
#define __SF_Clhapdf_

#define f2cFortran

#include "cfortran.h"

PROTOCCALLSFSUB1(initpdfset,initpdfset,STRINGV)
#define initpdfset(name) \
CCALLSFSUB1(initpdfset,initpdfset,STRINGV,name) 

PROTOCCALLSFSUB1(initpdf,initpdf,INT)
#define initpdf(mem) \
CCALLSFSUB1(initpdf,initpdf,INT,mem) 

PROTOCCALLSFSUB2(getlam5,getlam5,INT,DOUBLE)
#define getlam5(mem,qcdl5) \
CCALLSFSUB2(getlam5,getlam5,INT,DOUBLE,mem,qcdl5)

PROTOCCALLSFSUB3(evolvepdf,evolvepdf,DOUBLE,DOUBLE,DOUBLEV)
#define evolvepdf(x,Q,pfg) \
CCALLSFSUB3(evolvepdf,evolvepdf,DOUBLE,DOUBLE,DOUBLEV,x,Q,pdf) 
/*
PROTOCCALLSFSUB1(getorderas,getorderas,INT)
#define getorderas(mem) \
CCALLSFSUB1(getorderas,getorderas,INT,order) 
*/
/* PROTOCCALLSFSUBn is optional for C, but mandatory for C++.

PROTOCCALLSFSUBn(ROUTINE_NAME,routine_name,argtype_1,...,argtype_n)
#define     Routine_name(argname_1,..,argname_n)               \
CCALLSFSUBn(ROUTINE_NAME,routine_name,argtype_1,...,argtype_n, argname_1,..,argname_n) 

PROTOCCALLSFFUNn(routine_type,ROUTINE_NAME,routine_name,argtype_1,...,argtype_n)
#define     Routine_name(argname_1,..,argname_n)               \
CCALLSFFUNn(ROUTINE_NAME,routine_name,argtype_1,...,argtype_n, argname_1,..,argname_n) 

*/

PROTOCCALLSFFUN1(DOUBLE,LHAPDFALPHAS,lhapdfalphas,DOUBLE)
#define lhapdfalphas(Q) \
CCALLSFFUN1(LHAPDFALPHAS,lhapdfalphas,DOUBLE,Q)

PROTOCCALLSFFUN2(DOUBLE,LHAPDFQCDLAM,lhapdfqcdlam,INT,INT)
#define lhapdfqcdlam(set,mem) \
CCALLSFFUN2(LHAPDFQCDLAM,lhapdfqcdlam,INT,INT,set,mem)

PROTOCCALLSFFUN0(INT,LHAPDFQCDORDER,lhapdfqcdorder)
#define lhapdfqcdorder() \
CCALLSFFUN0(LHAPDFQCDORDER,lhapdfqcdorder)

#endif
